# Resource files

This document lists the files used by pybo, their format, origin and usage. Unless indicated otherwise they are in the public domain.

### SylComponents.json

This file has been compiled by hand based on the list presented in *TODO: ref. to HL article*

It is used to check if a syllable is correct according to Classical Tibetan norms, and find the root letter.

### frequency/mgd.txt

XXX

### frequency/tc.txt

XXX

### lemmas/particles.yaml

XXX

### trie/ancient.txt , trie/exceptions.txt

These files come from [tibetan-spellchecker](https://github.com/eroux/tibetan-spellchecker) and indicate exceptions to Classical Tibetan norms.

### trie/particles.txt

This is a list of all particles, compiled by hand, with the `PART` POS tag.

### trie/Tibetan.DICT

This file has been extracted from:

Meelen, Marieke, Hill, Nathan, & Handy, Christopher. (2017). The Annotated Corpus of Classical Tibetan (ACTib), Part II - POS-tagged version, based on the BDRC digitised text collection, tagged with the Memory-Based Tagger from TiMBL [Data set]. Zenodo. [http://doi.org/10.5281/zenodo.822537](https://doi.org/10.5281/zenodo.822537)

It is available under the [CC-BY 4.0 license](https://creativecommons.org/licenses/by/4.0/).

### trie/tsikchen.txt

This file has been extracted from a digitized version of:

[Yisun, Zhang. 1985. བོད་རྒྱ་ཚིག་མཛོད་ཆེན་མོ།. Beijing: མི་རིགས་དཔེ་སྐྲུན་ཁང་།](http://tbrc.org/link?RID=W29329)

Although the book is under copyright, we consider that the bare list of words we provide is not.

### trie/mgd.txt

XXX


### trie/recordings_4.txt , trie/oral_corpus_0.txt , trie/oral_corpus_1.txt , trie/oral_corpus_2.txt , trie/oral_corpus_3.txt

XXX
